//#define XERR
#include "densities.ih"

Densities::Densities(Scenario const &scenario)
:
    d_error(Error::instance())
{
    auto range = scenario.lines(s_id);

    for (auto iter = range.pair.first; iter != range.pair.second; ++iter)
    {
        if (not add(range.src, *iter))
            break;
    }
}
